# Python Kaos Utils

Set of utilities and helpers for rapid development of Python applications

Documentation: https://py-kaos-utils.readthedocs.io/en/release-0.1.0/

## Development and Testing

### IDE Setup

Add the `example` directory to the `PYTHONPATH` in your IDE to avoid seeing import warnings in the `tests` modules. If
you are using PyCharm, this is already set up.

### Running the Tests

Install requirements

```
pip install -r requirements.txt
```

For local environment

```
pytest
```

For all supported environments

```
tox
```
